function [rfp,rfp_back,rfp_dist] = main_data_extraction

[X,Y] = xlsread('filename.xlsx',1);%list of images to process
pre1 = 'path1\';%path of image files
countfolder = 'path2\';%path of the function
[TotalFiles,~] = size(X);%the total number of folders that need to be processed

%Values to be calculated
rfp = zeros(TotalFiles,5);%fluorescence intensity of RFP
rfp_back = zeros(TotalFiles,5);%background fluorescence intensity of RFP
rfp_dist = zeros(TotalFiles,5,26);%fluorescence intensity of RFP at various locations in the diagonal region
gfp = zeros(TotalFiles,5);%fluorescence intensity of GFP
gfp_back = zeros(TotalFiles,5);%background fluorescence intensity of GFP
gfp_dist = zeros(TotalFiles,5,26);%fluorescence intensity of GFP at various locations in the diagonal region

%load the images
for i1 = 1:TotalFiles
    condition = Y{i1+1,2};
    filename = Y{i1+1,3};
    num = X(i1,1);
    bacteria = X(i1,4);
    cs = X(i1,5);
    size = X(i1,6);
    od = X(i1,7);
    other = X(i1,8);
    amp = X(i1,9);
    ratio = X(i1,11);
    sample_num = X(i1,12);
    time = X(i1,13);
    date = num2str(X(i1,10));
    
    pre2 = cellstr(condition);
    pre3 = cellstr(date);
    file = fullfile(pre1,condition,date);
    rfp_peak = X(i1,19);
    gfp_peak = X(i1,20);
       
    %decide which folders to read based on the type of bacteria
    if  bacteria == 1 ||  bacteria == 3 %only the bacteria labeled RFP are used
        fileFolder1 = fullfile(file,'\rfp');
        fileFolder2 = [];
    elseif bacteria == 2 ||  bacteria == 4 || bacteria == 5 %only the bacteria labeled GFP are used
        fileFolder1 = [];
        fileFolder2 = fullfile(file,'\gfp');
    elseif bacteria == 0 %blank control
        if strcmp(pre2{1,1},'blank_gfp')
            fileFolder1 = [];
            fileFolder2 = fullfile(file,'\gfp');
        elseif strcmp(pre2{1,1},'blank_rfp')
            fileFolder1 = fullfile(file,'\rfp');
            fileFolder2 = [];
        else %both the bacteria labeled RFP and GFP are used
            fileFolder1 = fullfile(file,'\rfp');
            fileFolder2 = fullfile(file,'\gfp');
        end
    else
        fileFolder1 = fullfile(file,'\\rfp');
        fileFolder2 = fullfile(file,'\\gfp');
    end
    
    dirOutput1 = dir(fullfile(fileFolder1,'*.*'));
    fileNames1 = {dirOutput1.name}';
    dirOutput2 = dir(fullfile(fileFolder2,'*.*'));
    fileNames2 = {dirOutput2.name}';
    %select the corresponding calculation program based on the type of chip
    if size == 0  %the strip chip is used
        cd(countfolder);
        [rfp(i1,1:5),rfp_back(i1,1:5),rfp_dist(i1,1:5,:)] = fun_chip_strip(fileFolder1,fileNames1,filename,'rfp',rfp_peak,countfolder);
        cd(countfolder);
        [gfp(i1,1:5),gfp_back(i1,1:5),gfp_dist(i1,1:5,:)] = fun_chip_strip(fileFolder2,fileNames2,filename,'gfp',gfp_peak,countfolder);
    end
    if size == 1600 %the 1600 m-chip is used
        cd(countfolder);
        [rfp(i1,1:5),rfp_back(i1,1:5),rfp_dist(i1,1:5,:)] = fun_chip_1600(fileFolder1,fileNames1,filename,'rfp',rfp_peak,countfolder);
        cd(countfolder);
        [gfp(i1,1:5),gfp_back(i1,1:5),gfp_dist(i1,1:5,:)] = fun_chip_1600(fileFolder2,fileNames2,filename,'gfp',gfp_peak,countfolder);
    end
    if size == 800 %the 800 m-chip is used
        cd(countfolder);
        [rfp(i1,1:5),rfp_back(i1,1:5),rfp_dist(i1,1:5,:)] = fun_chip_800(fileFolder1,fileNames1,filename,'rfp',rfp_peak,countfolder);
        cd(countfolder);
        [gfp(i1,1:5),gfp_back(i1,1:5),gfp_dist(i1,1:5,:)] = fun_chip_800(fileFolder2,fileNames2,filename,'gfp',gfp_peak,countfolder);
    end
    if size == 400 %the 400 m-chip is used
        cd(countfolder);
        [rfp(i1,1:5),rfp_back(i1,1:5),rfp_dist(i1,1:5,:)] = fun_chip_400(fileFolder1,fileNames1,filename,'rfp',rfp_peak,countfolder);
        cd(countfolder);
        [gfp(i1,1:5),gfp_back(i1,1:5),gfp_dist(i1,1:5,:)] = fun_chip_400(fileFolder2,fileNames2,filename,'gfp',gfp_peak,countfolder);
    end
end

